aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/mds-respawn.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/mds-respawn.c b/src/mds-respawn.c
index 6072ad9..bcbb7fe 100644
--- a/src/mds-respawn.c
+++ b/src/mds-respawn.c
@@ -207,8 +207,9 @@ static void spawn_server(size_t index)
return;
}
- /* In the child process (server): change execution image to the server.. */
+ /* In the child process (server): remove the alarm and change execution image to the server.. */
+ alarm(0);
execvp(commands[index][0], commands[index]);
xperror(commands[index][0]);
_exit(1);